.. include:: ../../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   basic
   advanced
   api
   changelog

License
-------

Copyright (c) 2014 by pyramid_localize authors and contributors. See :ref:`authors`

This module is part of pyramid_fullauth and is released under
the MIT License (MIT): http://opensource.org/licenses/MIT
